==> qtjambi-webenginewidgets-5.15.9-sources.jar: io/qt/webengine/widgets/QWebEngineScriptCollection.java <==
package io.qt.webengine.widgets;


/**
 * <p>Represents a collection of user scripts</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qwebenginescriptcollection.html">QWebEngineScriptCollection</a></p>
 */
public final class QWebEngineScriptCollection extends io.qt.QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    @io.qt.QtUninvokable
    public final void clear(){
        clear_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clear_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean contains(io.qt.webengine.widgets.QWebEngineScript value){
        return contains_native_cref_QWebEngineScript_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(value));
    }
    
    @io.qt.QtUninvokable
    private native boolean contains_native_cref_QWebEngineScript_constfct(long __this__nativeId, long value);
    
    @io.qt.QtUninvokable
    public final int count(){
        return count_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int count_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final io.qt.webengine.widgets.QWebEngineScript findScript(java.lang.String name){
        return findScript_native_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), name);
    }
    
    @io.qt.QtUninvokable
    private native io.qt.webengine.widgets.QWebEngineScript findScript_native_cref_QString_constfct(long __this__nativeId, java.lang.String name);
    
    @io.qt.QtUninvokable
    public final io.qt.core.QList<io.qt.webengine.widgets.QWebEngineScript> findScripts(java.lang.String name){
        return findScripts_native_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), name);
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QList<io.qt.webengine.widgets.QWebEngineScript> findScripts_native_cref_QString_constfct(long __this__nativeId, java.lang.String name);
    
    @io.qt.QtUninvokable
    public final void insert(java.util.Collection<? extends io.qt.webengine.widgets.QWebEngineScript> list){
        insert_native_cref_QList(QtJambi_LibraryUtilities.internal.nativeId(this), list);
    }
    
    @io.qt.QtUninvokable
    private native void insert_native_cref_QList(long __this__nativeId, java.util.Collection<? extends io.qt.webengine.widgets.QWebEngineScript> list);
    
    @io.qt.QtUninvokable
    public final void insert(io.qt.webengine.widgets.QWebEngineScript arg__1){
        insert_native_cref_QWebEngineScript(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(arg__1));
    }
    
    @io.qt.QtUninvokable
    private native void insert_native_cref_QWebEngineScript(long __this__nativeId, long arg__1);
    
    @io.qt.QtUninvokable
    public final boolean isEmpty(){
        return isEmpty_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isEmpty_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean remove(io.qt.webengine.widgets.QWebEngineScript arg__1){
        return remove_native_cref_QWebEngineScript(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(arg__1));
    }
    
    @io.qt.QtUninvokable
    private native boolean remove_native_cref_QWebEngineScript(long __this__nativeId, long arg__1);
    
    @io.qt.QtUninvokable
    public final int size(){
        return size_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int size_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final io.qt.core.QList<io.qt.webengine.widgets.QWebEngineScript> toList(){
        return toList_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QList<io.qt.webengine.widgets.QWebEngineScript> toList_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QWebEngineScriptCollection(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-webenginewidgets-5.15.10-sources.jar: io/qt/webengine/widgets/QWebEngineScriptCollection.java <==
package io.qt.webengine.widgets;


/**
 * <p>Represents a collection of user scripts</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qwebenginescriptcollection.html">QWebEngineScriptCollection</a></p>
 */
public final class QWebEngineScriptCollection extends io.qt.QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    @io.qt.QtUninvokable
    public final void clear(){
        clear_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clear_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean contains(io.qt.webengine.widgets.QWebEngineScript value){
        return contains_native_cref_QWebEngineScript_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(value));
    }
    
    @io.qt.QtUninvokable
    private native boolean contains_native_cref_QWebEngineScript_constfct(long __this__nativeId, long value);
    
    @io.qt.QtUninvokable
    public final int count(){
        return count_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int count_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final io.qt.webengine.widgets.QWebEngineScript findScript(java.lang.String name){
        return findScript_native_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), name);
    }
    
    @io.qt.QtUninvokable
    private native io.qt.webengine.widgets.QWebEngineScript findScript_native_cref_QString_constfct(long __this__nativeId, java.lang.String name);
    
    @io.qt.QtUninvokable
    public final io.qt.core.QList<io.qt.webengine.widgets.QWebEngineScript> findScripts(java.lang.String name){
        return findScripts_native_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), name);
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QList<io.qt.webengine.widgets.QWebEngineScript> findScripts_native_cref_QString_constfct(long __this__nativeId, java.lang.String name);
    
    @io.qt.QtUninvokable
    public final void insert(java.util.Collection<? extends io.qt.webengine.widgets.QWebEngineScript> list){
        insert_native_cref_QList(QtJambi_LibraryUtilities.internal.nativeId(this), list);
    }
    
    @io.qt.QtUninvokable
    private native void insert_native_cref_QList(long __this__nativeId, java.util.Collection<? extends io.qt.webengine.widgets.QWebEngineScript> list);
    
    @io.qt.QtUninvokable
    public final void insert(io.qt.webengine.widgets.QWebEngineScript arg__1){
        insert_native_cref_QWebEngineScript(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(arg__1));
    }
    
    @io.qt.QtUninvokable
    private native void insert_native_cref_QWebEngineScript(long __this__nativeId, long arg__1);
    
    @io.qt.QtUninvokable
    public final boolean isEmpty(){
        return isEmpty_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isEmpty_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean remove(io.qt.webengine.widgets.QWebEngineScript arg__1){
        return remove_native_cref_QWebEngineScript(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(arg__1));
    }
    
    @io.qt.QtUninvokable
    private native boolean remove_native_cref_QWebEngineScript(long __this__nativeId, long arg__1);
    
    @io.qt.QtUninvokable
    public final int size(){
        return size_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int size_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final io.qt.core.QList<io.qt.webengine.widgets.QWebEngineScript> toList(){
        return toList_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QList<io.qt.webengine.widgets.QWebEngineScript> toList_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QWebEngineScriptCollection(QPrivateConstructor p) { super(p); } 
    
}
